@@ -16,7 +16,7 @@ use constant {
 use Carp qw/croak confess/;
 use Scalar::Util 'blessed';
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 # required
 has 'dbh', is => 'ro', required => 1;
@@ -102,6 +102,23 @@ sub BUILD {
     }
 }
 
+sub connect {
+    my ($class, $dsn, $user, $pass, $attrs, $constructor_params) = @_;
+
+    croak 'Missing $dsn argument for connect()' unless $dsn;
+
+    croak "connect() must be called as a class method."
+        if ref $class;
+
+    $constructor_params //= {};
+
+    $constructor_params->{dbh} = DBI->connect($dsn, $user, $pass, $attrs)
+        or die $DBI::errstr;
+
+    $class->new($constructor_params);
+}
+
+
 sub db_driver_name {
     shift->dbh->{Driver}{Name};
 }
@@ -476,7 +493,7 @@ attributes to an existing entity type is very easy and cheap.
 
 The actual attribute data stored in one of the value tables. There is one value
 table for each data type.
-See L<data_types>, L<DBIx::EAV::Schema>.
+See L</data_types>, L<DBIx::EAV::Schema>.
 
 =head2 Physical Schema
 
@@ -487,7 +504,7 @@ L<DBIx::EAV::Schema>.
 
 Its the total set of Entity Types registered on the system, which form the
 actual application business model.
-See L<register_schema>.
+See L</register_schema>.
 
 =head2 ResultSet
 
@@ -506,6 +523,17 @@ through SELECT queries.
 
 =head2 connect
 
+=over
+
+=item Arguments: $dsn, $user, $pass, $attrs, $constructor_params
+
+=item Return Value: $eav
+
+=back
+
+Connects to the database via C<< DBI->connect($dsn, $user, $pass, $attrs) >>
+then returns a new instance via L</new>.
+
 =head1 METHODS
 
 =head2 register_schema
@@ -520,7 +548,7 @@ through SELECT queries.
 
 Register entity types specified in \%schema, where each key is the name of the
 entity and the value is a hashref describing its attributes and relationships.
-Described in detail in L<ENTITY DEFINITION>.
+Described in detail in L<DBIx::EAV::EntityType/"ENTITY DEFINITION">.
 
 
 =head2 resultset
@@ -571,7 +599,7 @@ Shortcut for C<< ->schema->table >>.
 
 =head2 data_types
 
-Returns an arrayref of data types known to the system. See L<new>.
+Returns an arrayref of data types known to the system. See L</new>.
 
 =head2 has_data_type
 
@@ -581,7 +609,7 @@ Returns an arrayref of data types known to the system. See L<new>.
 
 =back
 
-Returns true if the data type C<$name> exists. See L<data_types>.
+Returns true if the data type C<$name> exists. See L</data_types>.
 
 =head2 db_driver_name
 
